Class: QSafe::APIKeysApi
- Inherits:
-
Object
- Object
- QSafe::APIKeysApi
- Defined in:
- lib/qsafe/api/api_keys_api.rb,
lib/qsafe-sdk/api/api_keys_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_api_key(create_api_key_request, opts = {}) ⇒ CreateApiKey201Response
Create API key (JWT only).
-
#create_api_key_with_http_info(create_api_key_request, opts = {}) ⇒ Array<(CreateApiKey201Response, Integer, Hash)>
Create API key (JWT only).
-
#get_api_key(key_id, opts = {}) ⇒ GetApiKey200Response
Get API key details (JWT only).
-
#get_api_key_usage(key_id, opts = {}) ⇒ GetApiKeyUsage200Response
Get API key usage stats (JWT only).
-
#get_api_key_usage_with_http_info(key_id, opts = {}) ⇒ Array<(GetApiKeyUsage200Response, Integer, Hash)>
Get API key usage stats (JWT only).
-
#get_api_key_with_http_info(key_id, opts = {}) ⇒ Array<(GetApiKey200Response, Integer, Hash)>
Get API key details (JWT only).
-
#initialize(api_client = ApiClient.default) ⇒ APIKeysApi
constructor
A new instance of APIKeysApi.
-
#list_api_keys(opts = {}) ⇒ ListApiKeys200Response
List API keys (JWT only).
-
#list_api_keys_with_http_info(opts = {}) ⇒ Array<(ListApiKeys200Response, Integer, Hash)>
List API keys (JWT only).
-
#rotate_api_key(key_id, opts = {}) ⇒ RotateApiKey200Response
Rotate API key — generates new key value (JWT only).
-
#rotate_api_key_with_http_info(key_id, opts = {}) ⇒ Array<(RotateApiKey200Response, Integer, Hash)>
Rotate API key — generates new key value (JWT only).
-
#update_api_key(key_id, update_api_key_request, opts = {}) ⇒ GetApiKey200Response
Update API key (JWT only).
-
#update_api_key_with_http_info(key_id, update_api_key_request, opts = {}) ⇒ Array<(GetApiKey200Response, Integer, Hash)>
Update API key (JWT only).
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ APIKeysApi
Returns a new instance of APIKeysApi.
19 20 21 |
# File 'lib/qsafe/api/api_keys_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/qsafe/api/api_keys_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_api_key(create_api_key_request, opts = {}) ⇒ CreateApiKey201Response
Create API key (JWT only)
26 27 28 29 |
# File 'lib/qsafe/api/api_keys_api.rb', line 26 def create_api_key(create_api_key_request, opts = {}) data, _status_code, _headers = create_api_key_with_http_info(create_api_key_request, opts) data end |
#create_api_key_with_http_info(create_api_key_request, opts = {}) ⇒ Array<(CreateApiKey201Response, Integer, Hash)>
Create API key (JWT only)
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/qsafe/api/api_keys_api.rb', line 35 def create_api_key_with_http_info(create_api_key_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: APIKeysApi.create_api_key ...' end # verify the required parameter 'create_api_key_request' is set if @api_client.config.client_side_validation && create_api_key_request.nil? fail ArgumentError, "Missing the required parameter 'create_api_key_request' when calling APIKeysApi.create_api_key" end # resource path local_var_path = '/api-keys' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_api_key_request) # return_type return_type = opts[:debug_return_type] || 'CreateApiKey201Response' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"APIKeysApi.create_api_key", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: APIKeysApi#create_api_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_api_key(key_id, opts = {}) ⇒ GetApiKey200Response
Get API key details (JWT only)
92 93 94 95 |
# File 'lib/qsafe/api/api_keys_api.rb', line 92 def get_api_key(key_id, opts = {}) data, _status_code, _headers = get_api_key_with_http_info(key_id, opts) data end |
#get_api_key_usage(key_id, opts = {}) ⇒ GetApiKeyUsage200Response
Get API key usage stats (JWT only)
154 155 156 157 |
# File 'lib/qsafe/api/api_keys_api.rb', line 154 def get_api_key_usage(key_id, opts = {}) data, _status_code, _headers = get_api_key_usage_with_http_info(key_id, opts) data end |
#get_api_key_usage_with_http_info(key_id, opts = {}) ⇒ Array<(GetApiKeyUsage200Response, Integer, Hash)>
Get API key usage stats (JWT only)
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/qsafe/api/api_keys_api.rb', line 164 def get_api_key_usage_with_http_info(key_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: APIKeysApi.get_api_key_usage ...' end # verify the required parameter 'key_id' is set if @api_client.config.client_side_validation && key_id.nil? fail ArgumentError, "Missing the required parameter 'key_id' when calling APIKeysApi.get_api_key_usage" end allowable_values = ["1h", "24h", "7d", "30d"] if @api_client.config.client_side_validation && opts[:'time_range'] && !allowable_values.include?(opts[:'time_range']) fail ArgumentError, "invalid value for \"time_range\", must be one of #{allowable_values}" end # resource path local_var_path = '/api-keys/{keyId}/usage'.sub('{' + 'keyId' + '}', CGI.escape(key_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'timeRange'] = opts[:'time_range'] if !opts[:'time_range'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetApiKeyUsage200Response' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"APIKeysApi.get_api_key_usage", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: APIKeysApi#get_api_key_usage\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_api_key_with_http_info(key_id, opts = {}) ⇒ Array<(GetApiKey200Response, Integer, Hash)>
Get API key details (JWT only)
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/qsafe/api/api_keys_api.rb', line 101 def get_api_key_with_http_info(key_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: APIKeysApi.get_api_key ...' end # verify the required parameter 'key_id' is set if @api_client.config.client_side_validation && key_id.nil? fail ArgumentError, "Missing the required parameter 'key_id' when calling APIKeysApi.get_api_key" end # resource path local_var_path = '/api-keys/{keyId}'.sub('{' + 'keyId' + '}', CGI.escape(key_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetApiKey200Response' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"APIKeysApi.get_api_key", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: APIKeysApi#get_api_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_api_keys(opts = {}) ⇒ ListApiKeys200Response
List API keys (JWT only)
223 224 225 226 |
# File 'lib/qsafe/api/api_keys_api.rb', line 223 def list_api_keys(opts = {}) data, _status_code, _headers = list_api_keys_with_http_info(opts) data end |
#list_api_keys_with_http_info(opts = {}) ⇒ Array<(ListApiKeys200Response, Integer, Hash)>
List API keys (JWT only)
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/qsafe/api/api_keys_api.rb', line 234 def list_api_keys_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: APIKeysApi.list_api_keys ...' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling APIKeysApi.list_api_keys, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling APIKeysApi.list_api_keys, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling APIKeysApi.list_api_keys, must be greater than or equal to 1.' end allowable_values = ["active", "revoked", "expired"] if @api_client.config.client_side_validation && opts[:'status'] && !allowable_values.include?(opts[:'status']) fail ArgumentError, "invalid value for \"status\", must be one of #{allowable_values}" end # resource path local_var_path = '/api-keys' # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListApiKeys200Response' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"APIKeysApi.list_api_keys", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: APIKeysApi#list_api_keys\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#rotate_api_key(key_id, opts = {}) ⇒ RotateApiKey200Response
Rotate API key — generates new key value (JWT only)
301 302 303 304 |
# File 'lib/qsafe/api/api_keys_api.rb', line 301 def rotate_api_key(key_id, opts = {}) data, _status_code, _headers = rotate_api_key_with_http_info(key_id, opts) data end |
#rotate_api_key_with_http_info(key_id, opts = {}) ⇒ Array<(RotateApiKey200Response, Integer, Hash)>
Rotate API key — generates new key value (JWT only)
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/qsafe/api/api_keys_api.rb', line 310 def rotate_api_key_with_http_info(key_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: APIKeysApi.rotate_api_key ...' end # verify the required parameter 'key_id' is set if @api_client.config.client_side_validation && key_id.nil? fail ArgumentError, "Missing the required parameter 'key_id' when calling APIKeysApi.rotate_api_key" end # resource path local_var_path = '/api-keys/{keyId}/rotate'.sub('{' + 'keyId' + '}', CGI.escape(key_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'RotateApiKey200Response' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"APIKeysApi.rotate_api_key", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: APIKeysApi#rotate_api_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_api_key(key_id, update_api_key_request, opts = {}) ⇒ GetApiKey200Response
Update API key (JWT only)
363 364 365 366 |
# File 'lib/qsafe/api/api_keys_api.rb', line 363 def update_api_key(key_id, update_api_key_request, opts = {}) data, _status_code, _headers = update_api_key_with_http_info(key_id, update_api_key_request, opts) data end |
#update_api_key_with_http_info(key_id, update_api_key_request, opts = {}) ⇒ Array<(GetApiKey200Response, Integer, Hash)>
Update API key (JWT only)
373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/qsafe/api/api_keys_api.rb', line 373 def update_api_key_with_http_info(key_id, update_api_key_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: APIKeysApi.update_api_key ...' end # verify the required parameter 'key_id' is set if @api_client.config.client_side_validation && key_id.nil? fail ArgumentError, "Missing the required parameter 'key_id' when calling APIKeysApi.update_api_key" end # verify the required parameter 'update_api_key_request' is set if @api_client.config.client_side_validation && update_api_key_request.nil? fail ArgumentError, "Missing the required parameter 'update_api_key_request' when calling APIKeysApi.update_api_key" end # resource path local_var_path = '/api-keys/{keyId}'.sub('{' + 'keyId' + '}', CGI.escape(key_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_api_key_request) # return_type return_type = opts[:debug_return_type] || 'GetApiKey200Response' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"APIKeysApi.update_api_key", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: APIKeysApi#update_api_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |