Class: QSafe::HealthApi
- Inherits:
-
Object
- Object
- QSafe::HealthApi
- Defined in:
- lib/qsafe/api/health_api.rb,
lib/qsafe-sdk/api/health_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_health(opts = {}) ⇒ GetHealth200Response
Health check Returns status of all internal services (Redis, ephemeral storage, API).
-
#get_health_with_http_info(opts = {}) ⇒ Array<(GetHealth200Response, Integer, Hash)>
Health check Returns status of all internal services (Redis, ephemeral storage, API).
-
#initialize(api_client = ApiClient.default) ⇒ HealthApi
constructor
A new instance of HealthApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/qsafe/api/health_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_health(opts = {}) ⇒ GetHealth200Response
Health check Returns status of all internal services (Redis, ephemeral storage, API).
26 27 28 29 |
# File 'lib/qsafe/api/health_api.rb', line 26 def get_health(opts = {}) data, _status_code, _headers = get_health_with_http_info(opts) data end |
#get_health_with_http_info(opts = {}) ⇒ Array<(GetHealth200Response, Integer, Hash)>
Health check Returns status of all internal services (Redis, ephemeral storage, API).
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/qsafe/api/health_api.rb', line 35 def get_health_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: HealthApi.get_health ...' end # resource path local_var_path = '/health' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetHealth200Response' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"HealthApi.get_health", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: HealthApi#get_health\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |