Class: QSafe::Keypair
- Inherits:
-
Object
- Object
- QSafe::Keypair
- Defined in:
- lib/qsafe/models/keypair.rb,
lib/qsafe-sdk/models/keypair.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#algorithm ⇒ Object
Returns the value of attribute algorithm.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#expires_at ⇒ Object
Returns the value of attribute expires_at.
-
#id ⇒ Object
Returns the value of attribute id.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#public_key ⇒ Object
Base64-encoded public key.
-
#purpose ⇒ Object
Returns the value of attribute purpose.
-
#revoked_at ⇒ Object
Returns the value of attribute revoked_at.
-
#status ⇒ Object
Returns the value of attribute status.
-
#tags ⇒ Object
Returns the value of attribute tags.
-
#usage_count ⇒ Object
Returns the value of attribute usage_count.
-
#usage_limit ⇒ Object
Returns the value of attribute usage_limit.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Keypair
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Keypair
Initializes the object
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/qsafe/models/keypair.rb', line 117 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `QSafe::Keypair` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `QSafe::Keypair`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'algorithm') self.algorithm = attributes[:'algorithm'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'purpose') self.purpose = attributes[:'purpose'] end if attributes.key?(:'public_key') self.public_key = attributes[:'public_key'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] end if attributes.key?(:'revoked_at') self.revoked_at = attributes[:'revoked_at'] end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'usage_count') self.usage_count = attributes[:'usage_count'] end if attributes.key?(:'usage_limit') self.usage_limit = attributes[:'usage_limit'] end end |
Instance Attribute Details
#algorithm ⇒ Object
Returns the value of attribute algorithm.
20 21 22 |
# File 'lib/qsafe/models/keypair.rb', line 20 def algorithm @algorithm end |
#created_at ⇒ Object
Returns the value of attribute created_at.
29 30 31 |
# File 'lib/qsafe/models/keypair.rb', line 29 def created_at @created_at end |
#expires_at ⇒ Object
Returns the value of attribute expires_at.
31 32 33 |
# File 'lib/qsafe/models/keypair.rb', line 31 def expires_at @expires_at end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/qsafe/models/keypair.rb', line 18 def id @id end |
#metadata ⇒ Object
Returns the value of attribute metadata.
35 36 37 |
# File 'lib/qsafe/models/keypair.rb', line 35 def @metadata end |
#public_key ⇒ Object
Base64-encoded public key
27 28 29 |
# File 'lib/qsafe/models/keypair.rb', line 27 def public_key @public_key end |
#purpose ⇒ Object
Returns the value of attribute purpose.
24 25 26 |
# File 'lib/qsafe/models/keypair.rb', line 24 def purpose @purpose end |
#revoked_at ⇒ Object
Returns the value of attribute revoked_at.
33 34 35 |
# File 'lib/qsafe/models/keypair.rb', line 33 def revoked_at @revoked_at end |
#status ⇒ Object
Returns the value of attribute status.
22 23 24 |
# File 'lib/qsafe/models/keypair.rb', line 22 def status @status end |
#tags ⇒ Object
Returns the value of attribute tags.
37 38 39 |
# File 'lib/qsafe/models/keypair.rb', line 37 def @tags end |
#usage_count ⇒ Object
Returns the value of attribute usage_count.
39 40 41 |
# File 'lib/qsafe/models/keypair.rb', line 39 def usage_count @usage_count end |
#usage_limit ⇒ Object
Returns the value of attribute usage_limit.
41 42 43 |
# File 'lib/qsafe/models/keypair.rb', line 41 def usage_limit @usage_limit end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/qsafe/models/keypair.rb', line 292 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = QSafe.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/qsafe/models/keypair.rb', line 84 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/qsafe/models/keypair.rb', line 66 def self.attribute_map { :'id' => :'id', :'algorithm' => :'algorithm', :'status' => :'status', :'purpose' => :'purpose', :'public_key' => :'publicKey', :'created_at' => :'createdAt', :'expires_at' => :'expiresAt', :'revoked_at' => :'revokedAt', :'metadata' => :'metadata', :'tags' => :'tags', :'usage_count' => :'usageCount', :'usage_limit' => :'usageLimit' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/qsafe/models/keypair.rb', line 268 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
107 108 109 110 111 112 113 |
# File 'lib/qsafe/models/keypair.rb', line 107 def self.openapi_nullable Set.new([ :'expires_at', :'revoked_at', :'usage_limit' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/qsafe/models/keypair.rb', line 89 def self.openapi_types { :'id' => :'String', :'algorithm' => :'String', :'status' => :'String', :'purpose' => :'String', :'public_key' => :'String', :'created_at' => :'Time', :'expires_at' => :'Time', :'revoked_at' => :'Time', :'metadata' => :'Hash<String, Object>', :'tags' => :'Array<String>', :'usage_count' => :'Integer', :'usage_limit' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/qsafe/models/keypair.rb', line 236 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && algorithm == o.algorithm && status == o.status && purpose == o.purpose && public_key == o.public_key && created_at == o.created_at && expires_at == o.expires_at && revoked_at == o.revoked_at && == o. && == o. && usage_count == o.usage_count && usage_limit == o.usage_limit end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'lib/qsafe/models/keypair.rb', line 363 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
255 256 257 |
# File 'lib/qsafe/models/keypair.rb', line 255 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
261 262 263 |
# File 'lib/qsafe/models/keypair.rb', line 261 def hash [id, algorithm, status, purpose, public_key, created_at, expires_at, revoked_at, , , usage_count, usage_limit].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
185 186 187 188 189 |
# File 'lib/qsafe/models/keypair.rb', line 185 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
339 340 341 |
# File 'lib/qsafe/models/keypair.rb', line 339 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/qsafe/models/keypair.rb', line 345 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
333 334 335 |
# File 'lib/qsafe/models/keypair.rb', line 333 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
193 194 195 196 197 198 199 200 201 202 |
# File 'lib/qsafe/models/keypair.rb', line 193 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' algorithm_validator = EnumAttributeValidator.new('String', ["KYBER512", "KYBER768", "KYBER1024", "DILITHIUM2", "DILITHIUM3", "DILITHIUM5"]) return false unless algorithm_validator.valid?(@algorithm) status_validator = EnumAttributeValidator.new('String', ["ACTIVE", "REVOKED", "EXPIRED"]) return false unless status_validator.valid?(@status) purpose_validator = EnumAttributeValidator.new('String', ["KEM", "SIGNATURE", "GENERAL"]) return false unless purpose_validator.valid?(@purpose) true end |