Class: QSafe::KeypairsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/qsafe/api/keypairs_api.rb,
lib/qsafe-sdk/api/keypairs_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ KeypairsApi

Returns a new instance of KeypairsApi.



19
20
21
# File 'lib/qsafe/api/keypairs_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/qsafe/api/keypairs_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#generate_keypair(generate_keypair_request, opts = {}) ⇒ GenerateKeypair201Response

Generate a new keypair Supports dual authentication (JWT or API key). Use ‘KYBER*` algorithms for encryption (KEM), `DILITHIUM*` for signing.

Parameters:

Returns:



27
28
29
30
# File 'lib/qsafe/api/keypairs_api.rb', line 27

def generate_keypair(generate_keypair_request, opts = {})
  data, _status_code, _headers = generate_keypair_with_http_info(generate_keypair_request, opts)
  data
end

#generate_keypair_with_http_info(generate_keypair_request, opts = {}) ⇒ Array<(GenerateKeypair201Response, Integer, Hash)>

Generate a new keypair Supports dual authentication (JWT or API key). Use &#x60;KYBER*&#x60; algorithms for encryption (KEM), &#x60;DILITHIUM*&#x60; for signing.

Parameters:

Returns:

  • (Array<(GenerateKeypair201Response, Integer, Hash)>)

    GenerateKeypair201Response data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/qsafe/api/keypairs_api.rb', line 37

def generate_keypair_with_http_info(generate_keypair_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: KeypairsApi.generate_keypair ...'
  end
  # verify the required parameter 'generate_keypair_request' is set
  if @api_client.config.client_side_validation && generate_keypair_request.nil?
    fail ArgumentError, "Missing the required parameter 'generate_keypair_request' when calling KeypairsApi.generate_keypair"
  end
  # resource path
  local_var_path = '/generate-keypair'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(generate_keypair_request)

  # return_type
  return_type = opts[:debug_return_type] || 'GenerateKeypair201Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyHeader', 'ApiKeyQuery', 'BearerAuth']

  new_options = opts.merge(
    :operation => :"KeypairsApi.generate_keypair",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: KeypairsApi#generate_keypair\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_keypairs(opts = {}) ⇒ ListKeypairs200Response

List keypairs

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer) — default: default to 1
  • :limit (Integer) — default: default to 10
  • :algorithm (String)
  • :status (String)
  • :key_type (String)
  • :created_after (Time)
  • :created_before (Time)
  • :search (String)

    Search in keypair metadata (alphanumeric, spaces, hyphens, underscores)

Returns:



101
102
103
104
# File 'lib/qsafe/api/keypairs_api.rb', line 101

def list_keypairs(opts = {})
  data, _status_code, _headers = list_keypairs_with_http_info(opts)
  data
end

#list_keypairs_with_http_info(opts = {}) ⇒ Array<(ListKeypairs200Response, Integer, Hash)>

List keypairs

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer) — default: default to 1
  • :limit (Integer) — default: default to 10
  • :algorithm (String)
  • :status (String)
  • :key_type (String)
  • :created_after (Time)
  • :created_before (Time)
  • :search (String)

    Search in keypair metadata (alphanumeric, spaces, hyphens, underscores)

Returns:

  • (Array<(ListKeypairs200Response, Integer, Hash)>)

    ListKeypairs200Response data, response status code and response headers



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/qsafe/api/keypairs_api.rb', line 117

def list_keypairs_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: KeypairsApi.list_keypairs ...'
  end
  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling KeypairsApi.list_keypairs, must be greater than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 1000
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling KeypairsApi.list_keypairs, must be smaller than or equal to 1000.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling KeypairsApi.list_keypairs, must be greater than or equal to 1.'
  end

  allowable_values = ["KYBER512", "KYBER768", "KYBER1024", "DILITHIUM2", "DILITHIUM3", "DILITHIUM5"]
  if @api_client.config.client_side_validation && opts[:'algorithm'] && !allowable_values.include?(opts[:'algorithm'])
    fail ArgumentError, "invalid value for \"algorithm\", must be one of #{allowable_values}"
  end
  allowable_values = ["ACTIVE", "REVOKED", "EXPIRED"]
  if @api_client.config.client_side_validation && opts[:'status'] && !allowable_values.include?(opts[:'status'])
    fail ArgumentError, "invalid value for \"status\", must be one of #{allowable_values}"
  end
  allowable_values = ["KEM", "SIGNATURE"]
  if @api_client.config.client_side_validation && opts[:'key_type'] && !allowable_values.include?(opts[:'key_type'])
    fail ArgumentError, "invalid value for \"key_type\", must be one of #{allowable_values}"
  end
  if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length > 100
    fail ArgumentError, 'invalid value for "opts[:"search"]" when calling KeypairsApi.list_keypairs, the character length must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length < 1
    fail ArgumentError, 'invalid value for "opts[:"search"]" when calling KeypairsApi.list_keypairs, the character length must be great than or equal to 1.'
  end

  # resource path
  local_var_path = '/keypairs'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'algorithm'] = opts[:'algorithm'] if !opts[:'algorithm'].nil?
  query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil?
  query_params[:'key_type'] = opts[:'key_type'] if !opts[:'key_type'].nil?
  query_params[:'created_after'] = opts[:'created_after'] if !opts[:'created_after'].nil?
  query_params[:'created_before'] = opts[:'created_before'] if !opts[:'created_before'].nil?
  query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListKeypairs200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyHeader', 'ApiKeyQuery', 'BearerAuth']

  new_options = opts.merge(
    :operation => :"KeypairsApi.list_keypairs",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: KeypairsApi#list_keypairs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#revoke_keypair(keypair_id, revoke_keypair_request, opts = {}) ⇒ RevokeKeypair200Response

Revoke a keypair

Parameters:

  • keypair_id (String)

    UUID v4 keypair identifier

  • revoke_keypair_request (RevokeKeypairRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



206
207
208
209
# File 'lib/qsafe/api/keypairs_api.rb', line 206

def revoke_keypair(keypair_id, revoke_keypair_request, opts = {})
  data, _status_code, _headers = revoke_keypair_with_http_info(keypair_id, revoke_keypair_request, opts)
  data
end

#revoke_keypair_with_http_info(keypair_id, revoke_keypair_request, opts = {}) ⇒ Array<(RevokeKeypair200Response, Integer, Hash)>

Revoke a keypair

Parameters:

  • keypair_id (String)

    UUID v4 keypair identifier

  • revoke_keypair_request (RevokeKeypairRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(RevokeKeypair200Response, Integer, Hash)>)

    RevokeKeypair200Response data, response status code and response headers



216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/qsafe/api/keypairs_api.rb', line 216

def revoke_keypair_with_http_info(keypair_id, revoke_keypair_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: KeypairsApi.revoke_keypair ...'
  end
  # verify the required parameter 'keypair_id' is set
  if @api_client.config.client_side_validation && keypair_id.nil?
    fail ArgumentError, "Missing the required parameter 'keypair_id' when calling KeypairsApi.revoke_keypair"
  end
  # verify the required parameter 'revoke_keypair_request' is set
  if @api_client.config.client_side_validation && revoke_keypair_request.nil?
    fail ArgumentError, "Missing the required parameter 'revoke_keypair_request' when calling KeypairsApi.revoke_keypair"
  end
  # resource path
  local_var_path = '/keypairs/{keypairId}/revoke'.sub('{' + 'keypairId' + '}', CGI.escape(keypair_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(revoke_keypair_request)

  # return_type
  return_type = opts[:debug_return_type] || 'RevokeKeypair200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyHeader', 'ApiKeyQuery', 'BearerAuth']

  new_options = opts.merge(
    :operation => :"KeypairsApi.revoke_keypair",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: KeypairsApi#revoke_keypair\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_keypair(keypair_id, update_keypair_request, opts = {}) ⇒ UpdateKeypair200Response

Update keypair metadata / tags

Parameters:

  • keypair_id (String)

    UUID v4 keypair identifier

  • update_keypair_request (UpdateKeypairRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



278
279
280
281
# File 'lib/qsafe/api/keypairs_api.rb', line 278

def update_keypair(keypair_id, update_keypair_request, opts = {})
  data, _status_code, _headers = update_keypair_with_http_info(keypair_id, update_keypair_request, opts)
  data
end

#update_keypair_with_http_info(keypair_id, update_keypair_request, opts = {}) ⇒ Array<(UpdateKeypair200Response, Integer, Hash)>

Update keypair metadata / tags

Parameters:

  • keypair_id (String)

    UUID v4 keypair identifier

  • update_keypair_request (UpdateKeypairRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(UpdateKeypair200Response, Integer, Hash)>)

    UpdateKeypair200Response data, response status code and response headers



288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/qsafe/api/keypairs_api.rb', line 288

def update_keypair_with_http_info(keypair_id, update_keypair_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: KeypairsApi.update_keypair ...'
  end
  # verify the required parameter 'keypair_id' is set
  if @api_client.config.client_side_validation && keypair_id.nil?
    fail ArgumentError, "Missing the required parameter 'keypair_id' when calling KeypairsApi.update_keypair"
  end
  # verify the required parameter 'update_keypair_request' is set
  if @api_client.config.client_side_validation && update_keypair_request.nil?
    fail ArgumentError, "Missing the required parameter 'update_keypair_request' when calling KeypairsApi.update_keypair"
  end
  # resource path
  local_var_path = '/keypairs/{keypairId}'.sub('{' + 'keypairId' + '}', CGI.escape(keypair_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(update_keypair_request)

  # return_type
  return_type = opts[:debug_return_type] || 'UpdateKeypair200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyHeader', 'ApiKeyQuery', 'BearerAuth']

  new_options = opts.merge(
    :operation => :"KeypairsApi.update_keypair",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: KeypairsApi#update_keypair\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end